*=================================================================;
*  Title:  PROGRAM 1  ASSIGN AHRQ INPATIENT QUALITY INDICATORS
*          TO INPATIENT RECORDS
*
*  Description:;
*         ASSIGNS THE OUTCOME OF INTEREST AND POPULATION AT RISK
*         INDICATORS TO INPATIENT RECORDS;
*
*          >>>  VERSION 3.1, March 2007 <<<
*
*  USER NOTE:  Make sure you have created the format library
*              using IQFMTS.SAS BEFORE running this program.
*
*=================================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_IQI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;

 TITLE2 'PROGRAM 1';
 TITLE3 'AHRQ INPATIENT QUALITY INDICATORS: ASSIGN QIS TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- INPATIENT QUALITY INDICATOR (IQI) NAMING CONVENTION:   --- ;
 * --- THE FIRST LETTER IDENTIFIES THE INPATIENT QUALITY      --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (O) OBSERVED RATES
                (E) EXPECTED RATES
                (R) RISK-ADJUSTED RATES
                (S) SMOOTHED RATES
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
 * --- THE SECOND LETTER IDENTIFIES THE IQI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ;
 * --- NEXT TWO CHARACTERS ARE ALWAYS 'IQ'. THE LAST TWO      --- ;
 * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
 * -------------------------------------------------------------- ;

 %MACRO ADDAPR;
    %IF &APRDRGFG EQ 1 %THEN &APRDRG &SEVERE &MORTAL;
 %MEND;
 
 DATA   OUT1.&OUTFILE1.
    (KEEP=KEY HOSPID DRG MDC AGE DISP ASOURCE MAREA YEAR DQTR
          AGECAT POPCAT SEXCAT RACECAT PAYCAT %ADDAPR
          TPIQ01-TPIQ02 TPIQ04-TPIQ09 TPIQ11-TPIQ25 TAIQ26-TAIQ29
          TPIQ30-TPIQ34 DISCWT);
 SET   IN1.&INFILE1.
    (KEEP=KEY DRG MDC SEX AGE PSTCO
          PAY1 HOSPID DISP ASOURCE RACE YEAR DQTR 
          DX1-DX&NDX. PR1-PR&NPR. %ADDAPR DISCWT);

 * -------------------------------------------------------------- ;
 * --- AREA, DIAGNOSIS AND PROCEDURE MACROS --------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MDX1(FMT);

 ((PUT(DX1,&FMT.) = '1'))

 %MEND;

 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1' ) OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1' ))

 %MEND;

 * -------------------------------------------------------------- ;
 * --- DELETE RECORDS WITH MISSING VALUES FOR AGE OR SEX--------- ;
 * -------------------------------------------------------------- ;
 IF SEX LE 0 THEN DELETE;
 IF AGE LT 0 THEN DELETE;

 * -------------------------------------------------------------- ;
 * --- SET MISSING DISCHARGE WEIGHT TO ONE              --------- ;
 * -------------------------------------------------------------- ;
 IF DISCWT LT 0 THEN DISCWT = 1;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 ATTRIB FIPSTCO LENGTH=$5
   LABEL='FIPS STATE COUNTY CODE';
 FIPSTCO = PUT(PSTCO,Z5.);

 ATTRIB FIPST LENGTH=$2
   LABEL='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);

 * -------------------------------------------------------------- ;
 * --- CONDITIONALLY DEFINE METRO AREAS (MA) FROM COUNTY CODES -- ;
 * -------------------------------------------------------------- ;
 %CTY2MA

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB PAYCAT LENGTH=3
   LABEL='PATIENT PRIMARY PAYER';

 SELECT (PAY1);
   WHEN (1)  PAYCAT = 1;
   WHEN (2)  PAYCAT = 2;
   WHEN (3)  PAYCAT = 3;
   WHEN (4)  PAYCAT = 4;
   WHEN (5)  PAYCAT = 5;
   OTHERWISE PAYCAT = 6;
 END; * SELECT PAY1 ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB RACECAT LENGTH=3
   LABEL='PATIENT RACE/ETHNICITY';

 SELECT (RACE);
   WHEN (1)  RACECAT = 1;
   WHEN (2)  RACECAT = 2;
   WHEN (3)  RACECAT = 3;
   WHEN (4)  RACECAT = 4;
   WHEN (5)  RACECAT = 5;
   OTHERWISE RACECAT = 6;
 END; * SELECT RACE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB AGECAT LENGTH=3
   LABEL='PATIENT AGE';

 SELECT;
   WHEN (      AGE < 18)  AGECAT = 0;
   WHEN (18 <= AGE < 40)  AGECAT = 1;
   WHEN (40 <= AGE < 65)  AGECAT = 2;
   WHEN (65 <= AGE < 75)  AGECAT = 3;
   WHEN (75 <= AGE     )  AGECAT = 4;
 END; * SELECT AGE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB SEXCAT LENGTH=3
   LABEL='PATIENT GENDER';

 SELECT (SEX);
   WHEN (1)  SEXCAT = 1;
   WHEN (2)  SEXCAT = 2;
 END; * SELECT SEX ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB POPCAT LENGTH=3
   LABEL='PATIENT AGE';

 POPCAT=PUT(AGE,AGEFMT.);

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL VOLUME INDICATORS ------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TPIQ01 LENGTH=3
   LABEL='VOLUME ESOPHAGEAL RESECTION (Numerator)'
 TPIQ02 LENGTH=3
   LABEL='VOLUME PANCREATIC RESECTION (Numerator)'
 TPIQ04 LENGTH=3
   LABEL='VOLUME AAA REPAIR (Numerator)'
 TPIQ05 LENGTH=3
   LABEL='VOLUME CABG (Numerator)'
 TPIQ06 LENGTH=3
   LABEL='VOLUME PTCA (Numerator)'
 TPIQ07 LENGTH=3
   LABEL='VOLUME CAROTID ENDARTERECTOMY (Num)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL MORTALITY INDICATORS --------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TPIQ08 LENGTH=3
   LABEL='IN-HOSP MORT ESOPHAGEAL RESECTION (Num)'
 TPIQ09 LENGTH=3                           
   LABEL='IN-HOSP MORT PANCREATIC RESECTION (Num)'
 TPIQ11 LENGTH=3
   LABEL='IN-HOSP MORT AAA REPAIR (Numerator)'
 TPIQ12 LENGTH=3
   LABEL='IN-HOSP MORT CABG (Numerator)'
 TPIQ13 LENGTH=3
   LABEL='IN-HOSP MORT CRANIOTOMY (Numerator)'
 TPIQ14 LENGTH=3
   LABEL='IN-HOSP MORT HIP REPLACEMENT (Numerator)'
;

 ATTRIB
 TPIQ15 LENGTH=3
   LABEL='IN-HOSP MORT AMI (Numerator)'
 TPIQ16 LENGTH=3
   LABEL='IN-HOSP MORT CHF (Numerator)'
 TPIQ17 LENGTH=3
   LABEL='IN-HOSP MORT STROKE (Numerator)'
 TPIQ18 LENGTH=3
   LABEL='IN-HOSP MORT GI HEMORRHAGE (Numerator)'
 TPIQ19 LENGTH=3
   LABEL='IN-HOSP MORT HIP FRACTURE (Numerator)'
 TPIQ20 LENGTH=3
   LABEL='IN-HOSP MORT PNEUMONIA (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL UTILIZATION INDICATORS ------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TPIQ21 LENGTH=3
   LABEL='CESAREAN SECTION DELIVERY (Numerator)'
 TPIQ22 LENGTH=3
   LABEL='VAG BTH AFT C-SECTION,UNCOMPLICATED(Num)'
 TPIQ23 LENGTH=3
   LABEL='LAPAROSCOPIC CHOLECYSTECTOMY (Numerator)'
 TPIQ24 LENGTH=3
   LABEL='INCIDENTAL APPENDECTOMY (Numerator)'
 TPIQ25 LENGTH=3
   LABEL='BI-LATERAL CATHETERIZATION (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL UTILIZATION INDICATORS ----------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TAIQ26 LENGTH=3
   LABEL='CORONARY ARTERY BYPASS GRAFT (Numerator)'
 TAIQ27 LENGTH=3
   LABEL='PTCA (Numerator)'
 TAIQ28 LENGTH=3
   LABEL='HYSTERECTOMY (Numerator)'
 TAIQ29 LENGTH=3
   LABEL='LAMINECTOMY AND/OR SPINAL FUSION (Num)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS ---- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TPIQ30 LENGTH=3
   LABEL='IN-HOSP MORT PTCA (Numerator)'
 TPIQ31 LENGTH=3
   LABEL='IN-HOSP MORT CAROTID ENDARTERECTMY (Num)'
 TPIQ32 LENGTH=3
   LABEL='IN-HOSP MORT AMI, w/o TRANSFERS (Num)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL UTILIZATION INDICATORS -- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TPIQ33 LENGTH=3
   LABEL='PRIMARY CESAREAN SECTION (Numerator)'
 TPIQ34 LENGTH=3
   LABEL='VBAC, ALL (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL VOLUME INDICATORS --------------- ;
 * -------------------------------------------------------------- ;

   * --- VOLUME ESOPHAGEAL RESECTION       --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND

      %MPR($PRESOPP.) THEN

      TPIQ01 = 1;

   * --- VOLUME PANCREATIC RESECTION       --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND

      %MPR($PRPANCP.) THEN

      TPIQ02 = 1;

   * --- VOLUME AAA REPAIR                 --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MDX($PRAAARD.) AND

      %MPR($PRAAARP.) THEN

      TPIQ04 = 1;

   * --- VOLUME CABG                       --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND

      %MPR($PRCABGP.) THEN

      TPIQ05 = 1;

   * --- VOLUME PTCA                       --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND 

      %MPR($PRPTCAP.) THEN

      TPIQ06 = 1;

   * --- VOLUME CAROTID ENDARTERECTOMY     --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MPR($PRCEATP.) THEN

      TPIQ07 = 1;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL MORTALITY INDICATORS ------------ ;
 * -------------------------------------------------------------- ;

   * --- IN-HOSP MORT ESOPHAGEAL RESECTION --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MDX($PRESOPD.) AND

      %MPR($PRESOPP.) THEN DO;

      TPIQ08 = 0;

      IF DISP = 20 THEN

         TPIQ08 = 1;

   END;

   * --- IN-HOSP MORT PANCREATIC RESECTION --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MDX($PRPANCD.) AND

      %MPR($PRPANCP.) THEN DO;

      TPIQ09 = 0;

      IF DISP = 20 THEN

         TPIQ09 = 1;

   END;

   * --- IN-HOSP MORT AAA REPAIR           --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MDX($PRAAARD.) AND

      %MPR($PRAAARP.) THEN DO;

      TPIQ11 = 0;

      IF DISP = 20 THEN

         TPIQ11 = 1;

   END;

   * --- IN-HOSP MORT CABG                 --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 40) AND

      %MPR($PRCABGP.) THEN DO;

      TPIQ12 = 0;

      IF DISP = 20 THEN

         TPIQ12 = 1;

   END;

   * --- IN-HOSP MORT CRANIOTOMY           --- ;

   IF DRG IN (1,2,528,529,530,543) AND (AGE >= 18) THEN DO;

      TPIQ13 = 0;
 
      IF DISP = 20 THEN

         TPIQ13 = 1;

      IF %MDX1($HTRAUID.) THEN TPIQ13 = .;
   
   END;

   * --- IN-HOSP MORT HIP REPLACEMENT      --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MPR($MTHIPRP.) AND

      %MDX($MTHIPRD.) THEN DO;

      TPIQ14 = 0;

      IF DISP = 20 THEN

         TPIQ14 = 1;

   END;

   * --- IN-HOSP MORT AMI                  --- ;

   IF (AGE >= 18) AND %MDX1($MRTAMID.) THEN DO;

      TPIQ15 = 0;
      TPIQ32 = 0;

      IF DISP = 20 THEN DO;

         TPIQ15 = 1;
         TPIQ32 = 1;

      END;

   END;

   * --- IN-HOSP MORT CHF                  --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) AND

      %MDX1($MRTCHFD.) THEN DO;

      TPIQ16 = 0;

      IF DISP = 20 THEN

         TPIQ16 = 1;

   END;

   * --- IN-HOSP MORT STROKE               --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) THEN DO;

      IF (YEAR < 2004 AND %MDX1($MRTCVDD.)) OR
         (YEAR = 2004 AND DQTR IN (1,2,3) AND %MDX1($MRTCVDD.)) OR
         (YEAR = 2004 AND DQTR IN (4) AND %MDX1($MRTCV2D.)) OR 
         (YEAR > 2004 AND %MDX1($MRTCV2D.))
      THEN DO;

         TPIQ17 = 0;

         IF DISP = 20 THEN
     
            TPIQ17 = 1;

      END;

   END;

   * --- IN-HOSP MORT GI HEMORRHAGE        --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) AND

      %MDX1($MRTGIHD.) THEN DO;

      TPIQ18 = 0;

      IF DISP = 20 THEN

         TPIQ18 = 1;

   END;

   * --- IN-HOSP MORT HIP FRACTURE         --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) AND

      %MDX1($MTHIPFD.) THEN DO;

      TPIQ19 = 0;

      IF DISP = 20 THEN

         TPIQ19 = 1;

   END;

   * --- IN-HOSP MORT PNEUMONIA            --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) AND

      %MDX1($MTPNEUD.) THEN DO;

      TPIQ20 = 0;

      IF DISP = 20 THEN

         TPIQ20 = 1;

   END;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL UTILIZATION INDICATORS ---------- ;
 * -------------------------------------------------------------- ;

   * --- CESAREAN SECTION DELIVERY         --- ;

   IF (370 <= DRG <= 375) THEN DO;

      TPIQ21 = 0;

      IF (370 <= DRG <= 371) OR 
         (%MPR($PRCSECP.) AND NOT %MPR($PRCSE2P.)) THEN

         TPIQ21 = 1;

      IF %MDX($PRCSECD.) OR %MPR($PRCSE3P.) THEN

         TPIQ21 = .;

   END;

   * --- VAGINAL BIRTH AFTER C-SECTION     --- ;

   IF (370 <= DRG <= 375) AND

      %MDX($PRVBACD.) THEN DO;

      TPIQ22 = 0;
      TPIQ34 = 0;

      IF (372 <= DRG <= 375) THEN DO;

         TPIQ22 = 1;
         TPIQ34 = 1;

      END;

      IF %MDX($PRCSECD.) OR %MPR($PRCSE3P.) THEN

         TPIQ22 = .;

   END;

   * --- LAPAROSCOPIC CHOLECYSTECTOMY      --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MPR($PRLAP2P.) AND

      %MDX($PRLAPOD.) THEN DO;

      TPIQ23 = 0;

      IF %MPR($PRLAPOP.) THEN

         TPIQ23 = 1;

   END;

   * --- INCIDENTAL APPENDECTOMY           --- ;

   IF MDC NOTIN (14,15) AND (AGE >=65 ) AND

      PUT(DRG,PRAPPNG.) = '1' THEN DO;

      TPIQ24=0;

      IF %MPR($PRAPPNP.) THEN

         TPIQ24 = 1;

   END;

   * --- BI-LATERAL CATHETERIZATION        --- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND %MPR($PRCAT2P.) AND

      %MDX($PRCATHD.) THEN DO;

      TPIQ25 = 0;

      IF %MPR($PRCATHP.) AND NOT %MDX($PRCAT2D.) THEN

         TPIQ25 = 1;

   END;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL UTILIZATION INDICATORS -------------- ;
 * -------------------------------------------------------------- ;

   * --- CORONARY ARTERY BYPASS GRAFT      --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 40) AND

      %MPR($PRCABGP.) THEN

      TAIQ26 = 1;

   * --- PTCA                              --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 40) AND 

      %MPR($PRPTCAP.) THEN

      TAIQ27 = 1;

   * --- HYSTERECTOMY                      --- ;

   IF MDC NOTIN (14,15) AND (SEX=2) AND (AGE >= 18) AND

      %MPR($PRHYSTP.) THEN DO;

      TAIQ28 = 1;

      * --- EXCLUDE GENITAL CANCER -------------------- ;
      IF %MDX($PRHYS1D.) THEN TAIQ28 = .;

      * --- EXCLUDE PELVIC OR LOWER ABDOMINAL --------- ;
      ELSE IF %MDX($PRHYS2D.) THEN TAIQ28 = .;

   END;

   * --- LAMINECTOMY AND/OR SPINAL FUSION  --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 18) AND

      %MPR($PRLAMIP.) THEN

      TAIQ29 = 1;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS - ;
 * -------------------------------------------------------------- ;

   * --- IN-HOSP MORTALITY PTCA            --- ;

   IF MDC NOTIN (14,15) AND (AGE >= 40) AND 

      %MPR($PRPTCAP.) THEN DO;

      TPIQ30 = 0;

      IF DISP = 20 THEN

         TPIQ30 = 1;

   END;

   * --- IN-HOSP MORT CAROTID ENDARTERECTMY--- ;

   IF MDC NOTIN (14,15) AND (AGE >=18) AND 

      %MPR($PRCEATP.) THEN DO;

      TPIQ31 = 0;

      IF DISP = 20 THEN

         TPIQ31 = 1;

   END;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT ADDIT'L PROVIDER LEVEL UTILIZATION INDICATORS -- ;
 * -------------------------------------------------------------- ;

   IF TPIQ21 NE . AND TPIQ22 EQ . THEN TPIQ33 = TPIQ21;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE CASES WITH MISSING VALUES FOR DISP OR ASOURCE  --- ;
 * -------------------------------------------------------------- ;

 IF (DISP LT 0) THEN DO;
   TPIQ08 = .;
   TPIQ09 = .;
   TPIQ11 = .;
   TPIQ12 = .;
   TPIQ13 = .;
   TPIQ14 = .;
   TPIQ15 = .;
   TPIQ16 = .;
   TPIQ17 = .;
   TPIQ18 = .;
   TPIQ19 = .;
   TPIQ20 = .;
   TPIQ30 = .;
   TPIQ31 = .;
   TPIQ32 = .;
 END;

 IF (ASOURCE LT 0) THEN 
   TPIQ32 = .;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 IF (ASOURCE = 2) THEN 
   TPIQ32 = .;

 * --- TRANSFER TO ANOTHER ACUTE ------------------ ;
 IF (DISP = 2) THEN DO;
   TPIQ08 = .;
   TPIQ09 = .;
   TPIQ11 = .;
   TPIQ12 = .;
   TPIQ13 = .;
   TPIQ14 = .;
   TPIQ15 = .;
   TPIQ16 = .;
   TPIQ17 = .;
   TPIQ18 = .;
   TPIQ19 = .;
   TPIQ20 = .;
   TPIQ30 = .;
   TPIQ31 = .;
   TPIQ32 = .;
 END;

RUN;

* --------------------------------- ;

PROC MEANS DATA=OUT1.&OUTFILE1. N NMISS MIN MAX MEAN SUM;
RUN;

PROC CONTENTS DATA=OUT1.&OUTFILE1. POSITION;
RUN;

PROC PRINT DATA=OUT1.&OUTFILE1.(OBS=24);
TITLE4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE1.";
RUN;
